@@ -150,6 +150,8 @@ static char *_agstrcanon(char *arg, char *buf)
 	else if (!(gv_isalnum(uc) || uc == '_' || !isascii(uc))) {
 	    needs_quotes = true;
 	    part_of_escape = false;
+	} else {
+	    part_of_escape = false;
 	}
 	*p++ = uc;
 	uc = *s++;
@@ -607,7 +609,7 @@ static int write_node(Agnode_t * n, iochan_t * ofile, Dict_t * d)
 static bool write_node_test(Agraph_t * g, Agnode_t * n,
 			   uint64_t pred_id)
 {
-    if (!node_in_subg(g, n) && has_no_predecessor_below(g, n, pred_id)) {
+    if (has_no_predecessor_below(g, n, pred_id) && !node_in_subg(g, n)) {
 	if (has_no_edges(g, n) || not_default_attrs(g, n))
 	    return true;
     }
