@@ -1,5 +1,6 @@
+/// @file
+/// @ingroup common_render
 #include <assert.h>
-#include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <common/render.h>
 #include <common/textspan_lut.h>
@@ -10,6 +11,7 @@
 #include <stddef.h>
 #include <stdio.h>
 #include <string.h>
+#include <util/agxbuf.h>
 
 // Currently we just store the width of every ASCII character, which seems to
 // produce good enough results. We could also store kerning metrics and line
@@ -773,8 +775,9 @@ get_metrics_for_font_family(const char *font_name) {
             font_name);
   char *warning_text = agxbuse(&warning);
   if (emit_once(warning_text)) {
-    fputs(warning_text, stderr);
+    agwarningf("%s", warning_text);
   }
+  agxbfree(&warning);
   return get_metrics_for_font_family("Times");
 }
 
@@ -801,10 +804,10 @@ estimate_character_width_canonical(const short variant_metrics[128],
     static bool warning_already_reported = false;
     if (!warning_already_reported) { // stderr spam prevention
       warning_already_reported = true;
-      fprintf(stderr,
-              "Warning: no value for width of non-ASCII character %u. Falling "
-              "back to width of space character\n",
-              character);
+      agwarningf(
+          "Warning: no value for width of non-ASCII character %u. Falling "
+          "back to width of space character\n",
+          character);
     }
     character = ' ';
   }
@@ -813,10 +816,10 @@ estimate_character_width_canonical(const short variant_metrics[128],
     static bool warning_already_reported = false;
     if (!warning_already_reported) { // stderr spam prevention
       warning_already_reported = true;
-      fprintf(stderr,
-              "Warning: no value for width of ASCII character %u. Falling back "
-              "to 0\n",
-              character);
+      agwarningf(
+          "Warning: no value for width of ASCII character %u. Falling back "
+          "to 0\n",
+          character);
     }
     width = 0;
   }
