@@ -14,11 +14,11 @@
  */
 
 #include <cgraph/list.h>
-#include <cgraph/streq.h>
 #include <math.h>
 #include	<dotgen/dot.h>
 #include	<stdbool.h>
 #include	<stddef.h>
+#include	<util/streq.h>
 
 DEFINE_LIST(edge_list, edge_t*)
 
