@@ -29,7 +29,6 @@
 
 #include <common/types.h>
 #include <common/usershape.h>
-#include <cgraph/agxbuf.h>
 #include <cgraph/gv_ctype.h>
 #include <cgraph/strview.h>
 #include <common/utils.h>
@@ -37,6 +36,7 @@
 #include <gvc/gvplugin.h>
 #include <gvc/gvcint.h>
 #include <gvc/gvcproc.h>
+#include <util/agxbuf.h>
 #include <util/alloc.h>
 
 extern char *Gvimagepath;
@@ -58,7 +58,7 @@ typedef struct {
 #define PS_MAGIC   "%!PS-Adobe-"
 #define BMP_MAGIC  "BM"
 #define GIF_MAGIC  "GIF8"
-#define JPEG_MAGIC "\xFF\xD8\xFF\xE0"
+#define JPEG_MAGIC "\xFF\xD8\xFF"
 #define PDF_MAGIC  "%PDF-"
 #define EPS_MAGIC  "\xC5\xD0\xD3\xC6"
 #define XML_MAGIC  "<?xml"
