@@ -77,8 +77,7 @@ static Image* gdiplus_loadimage(GVJ_t * job, usershape_t *us)
 static void gdiplus_loadimage_gdiplus(GVJ_t * job, usershape_t *us, boxf b, bool)
 {
 	/* get the image from usershape details, then blit it to the context */
-	Image *image = gdiplus_loadimage(job, us);
-	if (image) {
+	if (Image *image = gdiplus_loadimage(job, us)) {
 		auto g = reinterpret_cast<Graphics*>(job->context);
 		g->DrawImage(image, RectF(b.LL.x, b.LL.y, b.UR.x - b.LL.x, b.UR.y - b.LL.y));
 	}
